@@ -37,15 +37,14 @@ DatabaseEncryptedPasswordBackend::DatabaseEncryptedPasswordBackend()
 {
     QSqlDatabase db = SqlDatabase::instance()->database();
     if (!db.tables().contains(QLatin1String("autofill_encrypted"))) {
-        db.exec("CREATE TABLE autofill_encrypted (data_encrypted TEXT, id INTEGER PRIMARY KEY,"
-                "password_encrypted TEXT, server TEXT, username_encrypted TEXT, last_used NUMERIC)");
-        db.exec("CREATE INDEX autofillEncryptedServer ON autofill_encrypted(server ASC)");
+        db.exec(QSL("CREATE TABLE autofill_encrypted (data_encrypted TEXT, id INTEGER PRIMARY KEY,"
+                "password_encrypted TEXT, server TEXT, username_encrypted TEXT, last_used NUMERIC)"));
+        db.exec(QSL("CREATE INDEX autofillEncryptedServer ON autofill_encrypted(server ASC)"));
     }
 }
 
 DatabaseEncryptedPasswordBackend::~DatabaseEncryptedPasswordBackend()
-{
-}
+= default;
 
 QStringList DatabaseEncryptedPasswordBackend::getUsernames(const QUrl &url)
 {
@@ -54,7 +53,7 @@ QStringList DatabaseEncryptedPasswordBackend::getUsernames(const QUrl &url)
     }
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT username_encrypted FROM autofill_encrypted WHERE server=? ORDER BY last_used DESC");
+    query.prepare(QSL("SELECT username_encrypted FROM autofill_encrypted WHERE server=? ORDER BY last_used DESC"));
     query.addBindValue(PasswordManager::createHost(url));
     query.exec();
 
@@ -74,8 +73,8 @@ QVector<PasswordEntry> DatabaseEncryptedPasswordBackend::getEntries(const QUrl &
     const QString host = PasswordManager::createHost(url);
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT id, username_encrypted, password_encrypted, data_encrypted FROM autofill_encrypted "
-                  "WHERE server=? ORDER BY last_used DESC");
+    query.prepare(QSL("SELECT id, username_encrypted, password_encrypted, data_encrypted FROM autofill_encrypted "
+                  "WHERE server=? ORDER BY last_used DESC"));
     query.addBindValue(host);
     query.exec();
 
@@ -105,7 +104,7 @@ QVector<PasswordEntry> DatabaseEncryptedPasswordBackend::getAllEntries()
     AesInterface aesDecryptor;
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT id, server, username_encrypted, password_encrypted, data_encrypted FROM autofill_encrypted");
+    query.prepare(QSL("SELECT id, server, username_encrypted, password_encrypted, data_encrypted FROM autofill_encrypted"));
     query.exec();
 
     if (query.next() && hasPermission()) {
@@ -141,7 +140,7 @@ void DatabaseEncryptedPasswordBackend::setActive(bool active)
     if (active) {
         setAskMasterPasswordState(isMasterPasswordSetted());
         if (!isMasterPasswordSetted()) {
-            // master-password is not setted this backend needs master-password
+            // master-password is not set this backend needs master-password
             showMasterPasswordDialog();
         }
     }
@@ -160,7 +159,7 @@ void DatabaseEncryptedPasswordBackend::addEntry(const PasswordEntry &entry)
     if (entry.data.isEmpty()) {
         // Multiple-usernames for HTTP/FTP authorization not supported
         QSqlQuery query(SqlDatabase::instance()->database());
-        query.prepare("SELECT username_encrypted FROM autofill_encrypted WHERE server=?");
+        query.prepare(QSL("SELECT username_encrypted FROM autofill_encrypted WHERE server=?"));
         query.addBindValue(entry.host);
         query.exec();
 
@@ -174,8 +173,8 @@ void DatabaseEncryptedPasswordBackend::addEntry(const PasswordEntry &entry)
 
     if (hasPermission() && encryptPasswordEntry(encryptedEntry, &aesEncryptor)) {
         QSqlQuery query(SqlDatabase::instance()->database());
-        query.prepare("INSERT INTO autofill_encrypted (server, data_encrypted, username_encrypted, password_encrypted, last_used) "
-                      "VALUES (?,?,?,?,strftime('%s', 'now'))");
+        query.prepare(QSL("INSERT INTO autofill_encrypted (server, data_encrypted, username_encrypted, password_encrypted, last_used) "
+                      "VALUES (?,?,?,?,strftime('%s', 'now'))"));
         query.bindValue(0, encryptedEntry.host);
         query.bindValue(1, encryptedEntry.data);
         query.bindValue(2, encryptedEntry.username);
@@ -194,13 +193,13 @@ bool DatabaseEncryptedPasswordBackend::updateEntry(const PasswordEntry &entry)
 
         // Data is empty only for HTTP/FTP authorization
         if (entry.data.isEmpty()) {
-            query.prepare("UPDATE autofill_encrypted SET username_encrypted=?, password_encrypted=? WHERE server=?");
+            query.prepare(QSL("UPDATE autofill_encrypted SET username_encrypted=?, password_encrypted=? WHERE server=?"));
             query.bindValue(0, encryptedEntry.username);
             query.bindValue(1, encryptedEntry.password);
             query.bindValue(2, encryptedEntry.host);
         }
         else {
-            query.prepare("UPDATE autofill_encrypted SET data_encrypted=?, username_encrypted=?, password_encrypted=? WHERE id=?");
+            query.prepare(QSL("UPDATE autofill_encrypted SET data_encrypted=?, username_encrypted=?, password_encrypted=? WHERE id=?"));
             query.addBindValue(encryptedEntry.data);
             query.addBindValue(encryptedEntry.username);
             query.addBindValue(encryptedEntry.password);
@@ -216,7 +215,7 @@ bool DatabaseEncryptedPasswordBackend::updateEntry(const PasswordEntry &entry)
 void DatabaseEncryptedPasswordBackend::updateLastUsed(PasswordEntry &entry)
 {
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("UPDATE autofill_encrypted SET last_used=strftime('%s', 'now') WHERE id=?");
+    query.prepare(QSL("UPDATE autofill_encrypted SET last_used=strftime('%s', 'now') WHERE id=?"));
     query.addBindValue(entry.id);
     query.exec();
 }
@@ -228,7 +227,7 @@ void DatabaseEncryptedPasswordBackend::removeEntry(const PasswordEntry &entry)
     }
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("DELETE FROM autofill_encrypted WHERE id=?");
+    query.prepare(QSL("DELETE FROM autofill_encrypted WHERE id=?"));
     query.addBindValue(entry.id);
     query.exec();
 
@@ -245,7 +244,7 @@ void DatabaseEncryptedPasswordBackend::removeAll()
     }
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("DELETE FROM autofill_encrypted");
+    query.prepare(QSL("DELETE FROM autofill_encrypted"));
     query.exec();
 
     m_stateOfMasterPassword = PasswordIsSetted;
@@ -265,7 +264,7 @@ bool DatabaseEncryptedPasswordBackend::hasSettings() const
 
 void DatabaseEncryptedPasswordBackend::showSettings(QWidget* parent)
 {
-    MasterPasswordDialog* masterPasswordDialog = new MasterPasswordDialog(this, parent);
+    auto* masterPasswordDialog = new MasterPasswordDialog(this, parent);
     masterPasswordDialog->showSettingPage();
 }
 
@@ -295,7 +294,7 @@ bool DatabaseEncryptedPasswordBackend::hasPermission()
 
     m_askPasswordDialogVisible = true;
 
-    AskMasterPassword* dialog = new AskMasterPassword(this);
+    auto* dialog = new AskMasterPassword(this);
 
     bool authorized = dialog->exec() == QDialog::Accepted;
 
@@ -349,7 +348,7 @@ bool DatabaseEncryptedPasswordBackend::encryptPasswordEntry(PasswordEntry &entry
 
 void DatabaseEncryptedPasswordBackend::showMasterPasswordDialog()
 {
-    MasterPasswordDialog* masterPasswordDialog = new MasterPasswordDialog(this, mApp->getWindow());
+    auto* masterPasswordDialog = new MasterPasswordDialog(this, mApp->getWindow());
     masterPasswordDialog->showSetMasterPasswordPage();
     masterPasswordDialog->delayedExec();
 }
@@ -393,7 +392,7 @@ void DatabaseEncryptedPasswordBackend::encryptDataBaseTableOnFly(const QByteArra
     }
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT id, data_encrypted, password_encrypted, username_encrypted, server FROM autofill_encrypted");
+    query.prepare(QSL("SELECT id, data_encrypted, password_encrypted, username_encrypted, server FROM autofill_encrypted"));
     query.exec();
 
     AesInterface encryptor;
@@ -423,7 +422,7 @@ void DatabaseEncryptedPasswordBackend::encryptDataBaseTableOnFly(const QByteArra
         }
 
         QSqlQuery updateQuery(SqlDatabase::instance()->database());
-        updateQuery.prepare("UPDATE autofill_encrypted SET data_encrypted = ?, password_encrypted = ?, username_encrypted = ? WHERE id = ?");
+        updateQuery.prepare(QSL("UPDATE autofill_encrypted SET data_encrypted = ?, password_encrypted = ?, username_encrypted = ? WHERE id = ?"));
         updateQuery.addBindValue(data);
         updateQuery.addBindValue(password);
         updateQuery.addBindValue(username);
@@ -439,7 +438,7 @@ QByteArray DatabaseEncryptedPasswordBackend::someDataFromDatabase()
     }
 
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT password_encrypted, data_encrypted, username_encrypted FROM autofill_encrypted");
+    query.prepare(QSL("SELECT password_encrypted, data_encrypted, username_encrypted FROM autofill_encrypted"));
     query.exec();
 
     QByteArray someData;
@@ -467,7 +466,7 @@ QByteArray DatabaseEncryptedPasswordBackend::someDataFromDatabase()
 void DatabaseEncryptedPasswordBackend::updateSampleData(const QByteArray &password)
 {
     QSqlQuery query(SqlDatabase::instance()->database());
-    query.prepare("SELECT id FROM autofill_encrypted WHERE server = ?");
+    query.prepare(QSL("SELECT id FROM autofill_encrypted WHERE server = ?"));
     query.addBindValue(INTERNAL_SERVER_ID);
     query.exec();
 
@@ -476,10 +475,10 @@ void DatabaseEncryptedPasswordBackend::updateSampleData(const QByteArray &passwo
         m_someDataStoredOnDataBase = aes.encrypt(AesInterface::createRandomData(16), password);
 
         if (query.next()) {
-            query.prepare("UPDATE autofill_encrypted SET password_encrypted = ? WHERE server=?");
+            query.prepare(QSL("UPDATE autofill_encrypted SET password_encrypted = ? WHERE server=?"));
         }
         else {
-            query.prepare("INSERT INTO autofill_encrypted (password_encrypted, server) VALUES (?,?)");
+            query.prepare(QSL("INSERT INTO autofill_encrypted (password_encrypted, server) VALUES (?,?)"));
         }
 
         query.addBindValue(QString::fromUtf8(m_someDataStoredOnDataBase));
@@ -489,7 +488,7 @@ void DatabaseEncryptedPasswordBackend::updateSampleData(const QByteArray &passwo
         m_stateOfMasterPassword = PasswordIsSetted;
     }
     else if (query.next()) {
-        query.prepare("DELETE FROM autofill_encrypted WHERE server = ?");
+        query.prepare(QSL("DELETE FROM autofill_encrypted WHERE server = ?"));
         query.addBindValue(INTERNAL_SERVER_ID);
         query.exec();
 
@@ -517,8 +516,8 @@ MasterPasswordDialog::MasterPasswordDialog(DatabaseEncryptedPasswordBackend* bac
     ui->currentPassword->setVisible(m_backend->isMasterPasswordSetted());
     ui->labelCurrentPassword->setVisible(m_backend->isMasterPasswordSetted());
 
-    connect(ui->setMasterPassword, SIGNAL(clicked()), this, SLOT(showSetMasterPasswordPage()));
-    connect(ui->clearMasterPassword, SIGNAL(clicked()), this, SLOT(clearMasterPasswordAndConvert()));
+    connect(ui->setMasterPassword, &QAbstractButton::clicked, this, &MasterPasswordDialog::showSetMasterPasswordPage);
+    connect(ui->clearMasterPassword, &QAbstractButton::clicked, this, &MasterPasswordDialog::clearMasterPasswordAndConvert);
     connect(ui->buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
     connect(ui->buttonBoxMasterPassword, SIGNAL(rejected()), this, SLOT(reject()));
     connect(ui->buttonBoxMasterPassword, SIGNAL(accepted()), this, SLOT(accept()));
@@ -531,7 +530,7 @@ MasterPasswordDialog::~MasterPasswordDialog()
 
 void MasterPasswordDialog::delayedExec()
 {
-    QTimer::singleShot(0, this, SLOT(exec()));
+    QTimer::singleShot(0, this, &QDialog::exec);
 }
 
 void MasterPasswordDialog::accept()
@@ -575,12 +574,12 @@ void MasterPasswordDialog::reject()
     QDialog::reject();
 
     if (m_backend->isActive() && !m_backend->isMasterPasswordSetted()) {
-        // master password not setted
+        // master password not set
         QMessageBox::information(this, AutoFill::tr("Warning!"),
                                  AutoFill::tr("This backend needs a master password to be set! "
                                               "Falkon just switches to its default backend"));
         // active default backend
-        mApp->autoFill()->passwordManager()->switchBackend("database");
+        mApp->autoFill()->passwordManager()->switchBackend(QSL("database"));
         return;
     }
 }
@@ -609,17 +608,17 @@ void MasterPasswordDialog::clearMasterPasswordAndConvert(bool forcedAskPass)
     }
 
     if (m_backend->hasPermission()) {
-        QVector<PasswordEntry> list = m_backend->getAllEntries();
-        PasswordBackend* databaseBackend = mApp->autoFill()->passwordManager()->availableBackends().value("database");
+        const QVector<PasswordEntry> list = m_backend->getAllEntries();
+        PasswordBackend* databaseBackend = mApp->autoFill()->passwordManager()->availableBackends().value(QSL("database"));
         if (!databaseBackend) {
             return;
         }
 
-        QVector<PasswordEntry> databaseList = databaseBackend->getAllEntries();
+        const QVector<PasswordEntry> databaseList = databaseBackend->getAllEntries();
         bool allDataMoved = true;
-        foreach (const PasswordEntry &entry, list) {
+        for (const PasswordEntry &entry : list) {
             bool sameEntry = false;
-            foreach (const PasswordEntry &dbEntry, databaseList) {
+            for (const PasswordEntry &dbEntry : databaseList) {
                 sameEntry = samePasswordEntry(dbEntry, entry);
                 if (sameEntry) {
                     allDataMoved = false;
@@ -638,11 +637,11 @@ void MasterPasswordDialog::clearMasterPasswordAndConvert(bool forcedAskPass)
             m_backend->removeMasterPassword();
             m_backend->setAskMasterPasswordState(false);
 
-            mApp->autoFill()->passwordManager()->switchBackend("database");
+            mApp->autoFill()->passwordManager()->switchBackend(QSL("database"));
         }
         else {
             QMessageBox::information(this, tr("Warning!"), tr("Some data has not been decrypted. The master password was not cleared!"));
-            mApp->autoFill()->passwordManager()->switchBackend("database");
+            mApp->autoFill()->passwordManager()->switchBackend(QSL("database"));
         }
     }
     reject();
@@ -669,8 +668,8 @@ AskMasterPassword::AskMasterPassword(DatabaseEncryptedPasswordBackend* backend,
     setWindowModality(Qt::ApplicationModal);
     setWindowTitle(AutoFill::tr("Enter Master Password"));
 
-    QVBoxLayout* verticalLayout = new QVBoxLayout(this);
-    QLabel* label = new QLabel(this);
+    auto* verticalLayout = new QVBoxLayout(this);
+    auto* label = new QLabel(this);
     label->setText(AutoFill::tr("Permission is required, please enter Master Password:"));
     m_lineEdit = new QLineEdit(this);
     m_lineEdit->setEchoMode(QLineEdit::Password);
@@ -689,9 +688,9 @@ AskMasterPassword::AskMasterPassword(DatabaseEncryptedPasswordBackend* backend,
     verticalLayout->addWidget(m_buttonBox);
     setLayout(verticalLayout);
 
-    connect(m_lineEdit, SIGNAL(returnPressed()), this, SLOT(verifyPassword()));
-    connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(verifyPassword()));
-    connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(m_lineEdit, &QLineEdit::returnPressed, this, &AskMasterPassword::verifyPassword);
+    connect(m_buttonBox, &QDialogButtonBox::accepted, this, &AskMasterPassword::verifyPassword);
+    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     setAttribute(Qt::WA_DeleteOnClose);
 }
